package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.util.ByteSequence;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/BranchInstruction.class */
public abstract class BranchInstruction extends Instruction implements InstructionTargeter {

    @Deprecated
    protected int index;

    @Deprecated
    protected InstructionHandle target;

    @Deprecated
    protected int position;

    /* JADX INFO: Access modifiers changed from: package-private */
    public static void notifyTarget(InstructionHandle oldIh, InstructionHandle newIh, InstructionTargeter t) {
        if (oldIh != null) {
            oldIh.removeTargeter(t);
        }
        if (newIh != null) {
            newIh.addTargeter(t);
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public BranchInstruction() {
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public BranchInstruction(short opcode, InstructionHandle target) {
        super(opcode, (short) 3);
        setTarget(target);
    }

    @Override // org.apache.bcel.generic.InstructionTargeter
    public boolean containsTarget(InstructionHandle ih) {
        return this.target == ih;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    @Override // org.apache.bcel.generic.Instruction
    public void dispose() {
        setTarget(null);
        this.index = -1;
        this.position = -1;
    }

    @Override // org.apache.bcel.generic.Instruction
    public void dump(DataOutputStream out) throws IOException {
        out.writeByte(super.getOpcode());
        this.index = getTargetOffset();
        if (!isValidShort(this.index)) {
            throw new ClassGenException("Branch target offset too large for short: " + this.index);
        }
        out.writeShort(this.index);
    }

    public final int getIndex() {
        return this.index;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public int getPosition() {
        return this.position;
    }

    public InstructionHandle getTarget() {
        return this.target;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public int getTargetOffset() {
        return getTargetOffset(this.target);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public int getTargetOffset(InstructionHandle target) {
        if (target == null) {
            throw new ClassGenException("Target of " + super.toString(true) + " is invalid null handle");
        }
        int t = target.getPosition();
        if (t < 0) {
            throw new ClassGenException("Invalid branch target position offset for " + super.toString(true) + ":" + t + ":" + target);
        }
        return t - this.position;
    }

    @Override // org.apache.bcel.generic.Instruction
    protected void initFromFile(ByteSequence bytes, boolean wide) throws IOException {
        super.setLength(3);
        this.index = bytes.readShort();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setIndex(int index) {
        this.index = index;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setPosition(int position) {
        this.position = position;
    }

    public void setTarget(InstructionHandle target) {
        notifyTarget(this.target, target, this);
        this.target = target;
    }

    @Override // org.apache.bcel.generic.Instruction
    public String toString(boolean verbose) {
        String s = super.toString(verbose);
        String t = "null";
        if (this.target != null) {
            if (verbose) {
                if (this.target.getInstruction() == this) {
                    t = "<points to itself>";
                } else if (this.target.getInstruction() == null) {
                    t = "<null instruction!!!?>";
                } else {
                    t = "" + this.target.getPosition();
                }
            } else {
                this.index = this.target.getPosition();
                t = "" + this.index;
            }
        }
        return s + " -> " + t;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public int updatePosition(int offset, int maxOffset) {
        this.position += offset;
        return 0;
    }

    @Override // org.apache.bcel.generic.InstructionTargeter
    public void updateTarget(InstructionHandle oldIh, InstructionHandle newIh) {
        if (this.target != oldIh) {
            throw new ClassGenException("Not targeting " + oldIh + ", but " + this.target);
        }
        setTarget(newIh);
    }
}
